@@ -1,5 +1,8 @@
 """The version information for nbformat."""
+
 # Use "hatchling version xx.yy.zz" to handle version changes
+from __future__ import annotations
+
 import re
 from importlib.metadata import version
 
@@ -21,7 +24,7 @@ _version_regex = re.compile(
     re.VERBOSE,
 )
 
-_version_fields = _version_regex.match(__version__).groupdict()  # type:ignore
+_version_fields = _version_regex.match(__version__).groupdict()  # type:ignore[union-attr]
 version_info = tuple(
     field
     for field in (
